## Changelog

Richard de Vos <rdevos72@gmail.com>
fhs_enyaq_data
fhs-enyaq-data

--------------------------------------------------------------
- 0.1.0: initial creation
- 0.1.1: small fixes in output
- 0.1.2: internal build
- 0.1.3: add mqtt support
- 0.1.4: fixing data

